/**
 \file com/st/p2012/mind/adl/DocumentationBackendFactory.java
 \brief A final class providing methods for instantiating a documentation backend.


 <B>
 \n
 This file is part of the Platform 2012 program,
 a cooperation between STMicroelectronics and CEA.\n
 Redistribution of this file to outside parties is
 strictly prohibited without the written consent
 of the module owner indicated below.\n
 </B>

 \par  Module owner: michel.metzger@st.com


 \par  Copyright (C) 2009 STMicroelectronics

 \par  Authors: ali-erdem.ozcan@st.com

 \par  Id: $Id$
 \par  Date: $Date$
 \par  Revision: $Rev$

 */

package com.st.p2012.mind.adl;

import org.objectweb.fractal.adl.xml.XMLNodeFactory;
import org.objectweb.fractal.adl.xml.XMLNodeFactoryImpl;
import org.objectweb.fractal.mind.BasicInputResourceLocator;
import org.objectweb.fractal.mind.InputResourceLocator;
import org.objectweb.fractal.mind.adl.BasicDefinitionCompiler;
import org.objectweb.fractal.mind.adl.DefinitionCompiler;
import org.objectweb.fractal.mind.adl.DefinitionSourceGenerator;
import org.objectweb.fractal.mind.adl.implementation.BasicImplementationLocator;
import org.objectweb.fractal.mind.adl.implementation.ImplementationLocator;
import org.objectweb.fractal.mind.compilation.CompilerWrapper;
import org.objectweb.fractal.mind.compilation.gcc.GccCompilerWrapper;
import org.objectweb.fractal.mind.idl.IDLLoader;
import org.objectweb.fractal.mind.idl.IDLLoaderChainFactory;
import org.objectweb.fractal.mind.idl.IDLVisitor;
import org.objectweb.fractal.mind.io.BasicOutputFileLocator;
import org.objectweb.fractal.mind.io.OutputFileLocator;
import org.objectweb.fractal.mind.preproc.BasicMPPWrapper;
import org.objectweb.fractal.mind.preproc.MPPWrapper;
import org.objectweb.fractal.mind.st.StringTemplateComponentLoader;
import org.objectweb.fractal.mind.st.templates.parser.StringTemplateLoader;

import com.st.p2012.mind.idl.IDLBackendFactory;

public final class DocumentationBackendFactory {
  private DocumentationBackendFactory() {
  }

  public static final DefinitionSourceGenerator newDefinitionSourceGenerator(
      final InputResourceLocator inputResourceLocator,
      final OutputFileLocator outputFileLocator, final IDLLoader idlLoader,
      final IDLVisitor idlCompiler,
      final StringTemplateComponentLoader stcLoader) {

    DefinitionSourceGenerator definitionSourceGenerator;
    final HTMLDocumentGenerator hdg = new HTMLDocumentGenerator();

    definitionSourceGenerator = hdg;

    hdg.inputResourceLocatorItf = inputResourceLocator;
    hdg.outputFileLocatorItf = outputFileLocator;

    // Life-cycle control
    hdg.templateGroupLoaderItf = stcLoader;

    return definitionSourceGenerator;
  }

  public static DefinitionCompiler newDefinitionCompiler(
      final DefinitionSourceGenerator definitionSourceGenerator,
      final ImplementationLocator implementationLocator,
      final OutputFileLocator outputFileLocator,
      final CompilerWrapper compilerWrapper, final MPPWrapper mppWrapper) {

    DefinitionCompiler definitionCompiler;
    final BasicDefinitionCompiler bdc = new BasicDefinitionCompiler();

    definitionCompiler = bdc;
    bdc.definitionSourceGeneratorItf = definitionSourceGenerator;
    bdc.implementationLocatorItf = implementationLocator;
    bdc.outputFileLocatorItf = outputFileLocator;
    bdc.compilerWrapperItf = compilerWrapper;
    bdc.mppWrapperItf = mppWrapper;

    return definitionCompiler;
  }

  public static DefinitionCompiler newDefinitionCompiler() {
    final IDLLoader idlLoader = IDLLoaderChainFactory.newLoader();
    final BasicInputResourceLocator inputResourceLocator = new BasicInputResourceLocator();
    final BasicOutputFileLocator outputFileLocator = new BasicOutputFileLocator();
    final ImplementationLocator implementationLocator = new BasicImplementationLocator();
    final StringTemplateComponentLoader stcLoader = new StringTemplateComponentLoader();
    final StringTemplateLoader templateLoader = new StringTemplateLoader();
    final XMLNodeFactory nodeFactory = new XMLNodeFactoryImpl();

    templateLoader.nodeFactoryItf = nodeFactory;
    stcLoader.loaderItf = templateLoader;

    final IDLVisitor idlCompiler = IDLBackendFactory.newIDLCompiler(idlLoader,
        inputResourceLocator, outputFileLocator, stcLoader);
    final DefinitionSourceGenerator definitionSourceGenerator = newDefinitionSourceGenerator(
        inputResourceLocator, outputFileLocator, idlLoader, idlCompiler,
        stcLoader);
    final CompilerWrapper compilerWrapper = new GccCompilerWrapper();
    final MPPWrapper mppWrapper = new BasicMPPWrapper();
    return newDefinitionCompiler(definitionSourceGenerator,
        implementationLocator, outputFileLocator, compilerWrapper, mppWrapper);
  }

}
