/**
 \file com/st/p2012/mind/comments/LinkComponentTag.java
 \brief A class to represent a "@component" tag in a comment.


 <B>
 \n
 This file is part of the Platform 2012 program,
 a cooperation between STMicroelectronics and CEA.\n
 Redistribution of this file to outside parties is
 strictly prohibited without the written consent
 of the module owner indicated below.\n
 </B>

 \par  Module owner: michel.metzger@st.com


 \par  Copyright (C) 2009 STMicroelectronics

 \par  Authors: michel.metzger@st.com

 \par  Id: $Id$
 \par  Date: $Date$
 \par  Revision: $Rev$

 */

package com.st.p2012.mind.comments;

import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToAttribute;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToInterface;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativeLinkToSubComponent;
import static com.st.p2012.mind.HTMLDocumentationHelper.getRelativePathToADL;

import com.st.p2012.mind.HTMLDocumentationHelper;
import com.st.p2012.mind.HTMLDocumentationHelper.SourceKind;
import com.st.p2012.mind.comments.LinkTag.ComponentLinkElementType;

public class LinkComponentTag extends LinkTag<ComponentLinkElementType> {

  public LinkComponentTag(final String target, final String subElemType, final String subElemName,
      final int beginIndex, final int endIndex) throws CommentParserException {
    super(target, subElemType, subElemName, beginIndex, endIndex);
  }

  @Override
  protected ComponentLinkElementType parseSubElemType(final String type) throws CommentParserException {
    try {
      return ComponentLinkElementType.valueOf(type.toUpperCase());
    } catch (final IllegalArgumentException e) {
      throw new CommentParserException();
    }
  }

  @Override
  protected  String getTargetHref(final String definitionName, final SourceKind sourceKind) {
    return getRelativePathToADL(definitionName, getTarget(), sourceKind);
  }

  @Override
  protected String getSubElemHref(final String definitionName, final SourceKind sourceKind) {
    switch (getSubElemType()) {
      case INTERFACES:
        return getRelativeLinkToInterface(definitionName, getTarget(), getSubElemName(), sourceKind);
      case ATTRIBUTES:
        return getRelativeLinkToAttribute(definitionName, getTarget(), getSubElemName(), sourceKind);
      case COMPONENTS:
        return getRelativeLinkToSubComponent(definitionName, getTarget(), getSubElemName(), sourceKind);
      default: return "";
    }
  }

  @Override
  protected String getSubElemTypeHref(final String definitionName,
      final SourceKind sourceKind) {
    switch (getSubElemType()) {
      case INTERFACES:
        return HTMLDocumentationHelper.getRelativeLinkToInterfaceSection(definitionName, getTarget(), sourceKind);
      case ATTRIBUTES:
        return HTMLDocumentationHelper.getRelativeLinkToAttributeSection(definitionName, getTarget(), sourceKind);
      case COMPONENTS:
        return HTMLDocumentationHelper.getRelativeLinkToSubComponentSection(definitionName, getTarget(), sourceKind);
      default: return "";
    }
  }

  @Override
  protected String getSubElemLabel() {
    switch (getSubElemType()) {
      case ATTRIBUTES:
        return "attribute";
      case COMPONENTS:
        return "component";
      case INTERFACES:
        return "interface";
      default : return "";
    }
  }
}
